@@ -54,6 +54,11 @@ class NumberFormat(str, Enum):
     WON = "won"
     YEN = "yen"
     YUAN = "yuan"
+    RUPIAH = "rupiah"
+    LIRA = "lira"
+    REAL = "real"
+    FRANC = "franc"
+    CANADIAN_DOLLAR = "canadian_dollar"
     HONG_KONG_DOLLAR = "hong_kong_dollar"
     NEW_ZEALAND_DOLLAR = "new_zealand_dollar"
     KRONA = "krona"
